@@ -1,9 +1,12 @@
 #!/usr/bin/env perl
 use Mojolicious::Lite -signatures;
 
-get '/'      => {text => $0};
-get '/block' => sub ($c) { $c->render_later; sleep 5 };
-get '/pid'   => {text => "pid=$$"};
+my $MPID = 0;
+
+get '/'           => {text => $0};
+get '/block'      => sub ($c) { $c->render_later; sleep 5 };
+get '/pid'        => {text => "pid=$$"};
+get '/ppid/:ppid' => sub ($c) { $MPID = $c->stash('ppid'); $c->render(text => $$); };
 
 get '/slow' => sub ($c) {
   my $t = $c->param('t') || 2;
@@ -15,6 +18,7 @@ get '/slow' => sub ($c) {
 app->hook(
   before_server_start => sub ($server, $app) {
     $app->log->debug(join ' ', ref $server, join ' ', @{$server->listen});
+    Mojo::IOLoop->recurring(0.01 => sub { $server->manager_pid($MPID) if $MPID });
   }
 );
 
